# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-07-18 15:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='delivery_method',
            field=models.PositiveIntegerField(choices=[(1, 'Self delivery'), (2, 'Nova Poshta'), (3, 'In Time'), (4, 'Gunsel'), (5, 'Avtoluks'), (6, 'Other')], default=None, verbose_name='Delivery method'),
        ),
        migrations.AlterField(
            model_name='order',
            name='email',
            field=models.EmailField(blank=True, max_length=255, null=True, verbose_name='Email'),
        ),
    ]
