# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-02-22 18:08
from __future__ import unicode_literals

from django.db import migrations, models

from shop.currencies.settings import CURRENCIES


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ExchangeRate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('currency', models.PositiveIntegerField(choices=CURRENCIES, unique=True, verbose_name='Currency')),
                ('value', models.FloatField(default=0, verbose_name='Value')),
            ],
            options={
                'verbose_name': 'Exchange rate',
                'verbose_name_plural': 'Exchange rate',
            },
        ),
    ]
